@@ -1,6 +1,12 @@
+import sphinx
 import re
 
 
+SPHINX_VERSION = tuple(
+    int(dig) for dig in re.findall("\d+", sphinx.__version__)
+)
+
+
 def striptags(text):
     return re.compile(r'<[^>]*>').sub('', text)
 
